
def generate_random_sequence(input_data, model, epochs=10):
    """
    Generate a random sequence using a trained Keras model.
    
    Args:
        input_data (numpy.ndarray): Input data to be fed into the model.
        model (keras.models.Model): Trained Keras model to generate the sequence.
        epochs (int, optional): Number of epochs to generate the sequence. Defaults to 10.
    """
    import numpy as np
    from keras.models import Sequential
    from keras.layers import LSTM, Dense

    # Initialize a Sequential model
    sequence_model = Sequential()

    # Add an LSTM layer with the same parameters as the original model
    sequence_model.add(LSTM(units=model.layers[0].units, return_sequences=True, input_shape=(input_data.shape[1], input_data.shape[2])))
    sequence_model.add(Dense(units=model.layers[1].units))

    # Compile the model
    sequence_model.compile(optimizer='adam', loss='mean_squared_error')

    # Generate the sequence
    for _ in range(epochs):
        # Generate a random sequence
        random_sequence = np.random.rand(input_data.shape[1], input_data.shape[2])
        # Predict the next value in the sequence
        prediction = sequence_model.predict(random_sequence)
        # Update the random sequence with the prediction
        random_sequence = np.vstack([random_sequence, prediction])

    return random_sequence



